summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMartin Klozik <martinx.klozik@intel.com>2016-11-23 09:18:26 +0000
committerGerrit Code Review <gerrit@opnfv.org>2016-11-23 09:18:26 +0000
commite0497a533007012318e4392aeab56f3010921bd2 (patch)
treeb0ae294cea1af39b7f29d15b5ea5bfd51af6c78f
parent64248beecb230957f77811c37e9f099917c0bc4f (diff)
parentbeff14c93c2ddb4996fa7cec09e7df69138862fa (diff)
Merge "ci: Use HTML report instead of PDF"
-rwxr-xr-xci/build-vsperf.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/ci/build-vsperf.sh b/ci/build-vsperf.sh
index 16e4625e..4d6acf70 100755
--- a/ci/build-vsperf.sh
+++ b/ci/build-vsperf.sh
@@ -67,7 +67,7 @@ TEST_REPORT_PARTIAL="*_test_report.rst"
TEST_REPORT_DIR="${WORKSPACE}/docs/results"
TEST_REPORT_INDEX="${TEST_REPORT_DIR}/index.rst"
TEST_REPORT_LINK_OLD="https://wiki.opnfv.org/wiki/vsperf_results"
-TEST_REPORT_FILE="${WORKSPACE}/docs_output/results/results.pdf"
+TEST_REPORT_FILE="${WORKSPACE}/docs_output/results/index.html"
TEST_REPORT_TARBALL="vswitchperf_logs_${DATE}.tar.gz"
if [[ "x${BRANCH}" == "xmaster" ]]; then
@@ -239,9 +239,9 @@ function generate_report() {
sed -ie 's,python ,python2 ,g' ./opnfvdocs/scripts/docs-build.sh
OPNFVDOCS_DIR='./opnfvdocs' ./opnfvdocs/scripts/docs-build.sh &> /dev/null
# store PDF with test results into dedicated directory
if [ -f $TEST_REPORT_FILE ] ; then
- cp -a $TEST_REPORT_FILE $TEST_REPORT_LOG_DIR
+ cp -ar $TEST_REPORT_FILE $(dirname $TEST_REPORT_FILE)/_static $TEST_REPORT_LOG_DIR
echo "Final test report has been created."
else
echo "FAILURE: Generation of final test report has failed."
@@ -239,9 +239,9 @@ function generate_report() {
sed -ie 's,python ,python2 ,g' ./opnfvdocs/scripts/docs-build.sh
OPNFVDOCS_DIR='./opnfvdocs' ./opnfvdocs/scripts/docs-build.sh &> /dev/null
- # store PDF with test results into dedicated directory
+ # store HTML report with test results into dedicated directory
if [ -f $TEST_REPORT_FILE ] ; then